@@ -39,12 +39,13 @@ class Firefox:
 
     def __init__(
         self,
-        cookies_id: Optional[str] = None,
         cookies_folder_path: Optional[str] = None,
         extensions_folder_path: Optional[str] = None,
         host: Optional[str] = None,
         port: Optional[int] = None,
+        cookies_id: Optional[str] = None,
         private: bool = False,
+        screen_size: Optional[Tuple[int, int]] = None, # (width, height)
         full_screen: bool = True,
         headless: bool = False,
         language: str = 'en-us',
@@ -116,12 +117,15 @@ class Firefox:
         profile.set_preference('useAutomationExtension', False)
 
         profile.set_preference("general.warnOnAboutConfig", False)
-
         profile.update_preferences()
-
         options = FirefoxOptions()
+
         if headless:
             options.add_argument("--headless")
+        
+        if screen_size is not None:
+            options.add_argument("--width=" + str(screen_size[0]))
+            options.add_argument("--height=" + str(screen_size[1]))
 
         self.driver = webdriver.Firefox(firefox_profile=profile, firefox_options=options)
 
@@ -217,7 +221,8 @@ class Firefox:
                                 self.get(org_url)
 
                                 return False
-        except:
+        except Exception as e:
+            print(e)
             self.get(org_url)
 
             return False
@@ -242,7 +247,7 @@ class Firefox:
 
         if clean_current == clean_new:
             return False
-        
+
         self.driver.get(url)
 
         return True
@@ -487,6 +492,15 @@ class Firefox:
                 current_tries = 1
 
 
+    # --------------------------------------------------------- Destructor ----------------------------------------------------------- #
+
+    def __del__(self):
+        try:
+            self.driver.quit()
+        except:
+            pass
+
+
     # ------------------------------------------------------- Private methods -------------------------------------------------------- #
 
     def __find(
